package cn.com.infosec.asn1.cms;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.BERSequence;
import cn.com.infosec.asn1.BERTaggedObject;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;

public class EncryptedContentInfo extends ASN1Encodable {
   private DERObjectIdentifier contentType;
   private AlgorithmIdentifier contentEncryptionAlgorithm;
   private ASN1OctetString encryptedContent;

   public EncryptedContentInfo(DERObjectIdentifier contentType, AlgorithmIdentifier contentEncryptionAlgorithm, ASN1OctetString encryptedContent) {
      this.contentType = contentType;
      this.contentEncryptionAlgorithm = contentEncryptionAlgorithm;
      this.encryptedContent = encryptedContent;
   }

   public EncryptedContentInfo(ASN1Sequence seq) {
      this.contentType = (DERObjectIdentifier)seq.getObjectAt(0);
      this.contentEncryptionAlgorithm = AlgorithmIdentifier.getInstance(seq.getObjectAt(1));
      if (seq.size() > 2) {
         this.encryptedContent = ASN1OctetString.getInstance((ASN1TaggedObject)seq.getObjectAt(2), false);
      }

   }

   public static EncryptedContentInfo getInstance(Object obj) {
      if (obj != null && !(obj instanceof EncryptedContentInfo)) {
         if (obj instanceof ASN1Sequence) {
            return new EncryptedContentInfo((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("Invalid EncryptedContentInfo: " + obj.getClass().getName());
         }
      } else {
         return (EncryptedContentInfo)obj;
      }
   }

   public DERObjectIdentifier getContentType() {
      return this.contentType;
   }

   public AlgorithmIdentifier getContentEncryptionAlgorithm() {
      return this.contentEncryptionAlgorithm;
   }

   public ASN1OctetString getEncryptedContent() {
      return this.encryptedContent;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.contentType);
      var10001.add(this.contentEncryptionAlgorithm);
      ASN1OctetString var3;
      if ((var3 = this.encryptedContent) != null) {
         BERTaggedObject var2;
         var2 = new BERTaggedObject.<init>(false, 0, var3);
         var1.add(var2);
      }

      return new BERSequence(var1);
   }
}
